Struct
QmiIndicationLocInjectTimeRequestOutput
since: 1.37
Description [src]
struct QmiIndicationLocInjectTimeRequestOutput {
/* No available fields */
}
The QmiIndicationLocInjectTimeRequestOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.37
Instance methods
qmi_indication_loc_inject_time_request_output_get_time_server_info
Get the ‘Time Server Info’ field from self.
since: 1.37
qmi_indication_loc_inject_time_request_output_ref
Atomically increments the reference count of self by one.
since: 1.37
qmi_indication_loc_inject_time_request_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.37