Struct
QmiIndicationVoiceSupplementaryServiceOutput
since: 1.30
Description [src]
struct QmiIndicationVoiceSupplementaryServiceOutput {
/* No available fields */
}
The QmiIndicationVoiceSupplementaryServiceOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.30
Instance methods
qmi_indication_voice_supplementary_service_output_get_info
Get the ‘Info’ field from self.
since: 1.30
qmi_indication_voice_supplementary_service_output_ref
Atomically increments the reference count of self by one.
since: 1.30
qmi_indication_voice_supplementary_service_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.30